@@ -176,10 +176,10 @@ class CustomDatasetV2(CustomDataset):
         normal_patch_upper_bound = normal_center + (self.patch_size/2) + 1
         normal_patch_lower_bound = normal_center - (self.patch_size/2 - 1)
         normal_patch_bound = np.concatenate((normal_patch_lower_bound.reshape(-1,1),normal_patch_upper_bound.reshape(-1,1)), axis = 1).astype(int)
-        normal_patch_images = self.images[:, normal_patch_bound[0][0] : normal_patch_bound[0][1],
+        normal_patch_images = images[:, normal_patch_bound[0][0] : normal_patch_bound[0][1],
                                           normal_patch_bound[1][0] : normal_patch_bound[1][1],
                                           normal_patch_bound[2][0] : normal_patch_bound[2][1]]
-        normal_patch_seg = self.seg[normal_patch_bound[0][0] : normal_patch_bound[0][1],
+        normal_patch_seg = seg[normal_patch_bound[0][0] : normal_patch_bound[0][1],
                                           normal_patch_bound[1][0] : normal_patch_bound[1][1],
                                           normal_patch_bound[2][0] : normal_patch_bound[2][1]]
         
@@ -306,7 +306,7 @@ class CustomDatasetV2(CustomDataset):
             result_seg = result_seg.to(self.device)
 
         if self.transform:
-            result_images, result_seg = self.transform(result_images, result_seg, self.info)
+            result_images, result_seg = self.transform(result_images, result_seg, info_data)
         
 
         return result_images, result_seg.long()
